@@ -9,7 +9,7 @@ __all__ = [
 
     'ClientError', 'ClientHttpProcessingError', 'ClientConnectionError',
     'ClientOSError', 'ClientTimeoutError', 'ProxyConnectionError',
-    'ClientRequestError', 'ClientResponseError']
+    'ClientRequestError', 'ClientResponseError', 'WSClientDisconnectedError']
 
 from asyncio import TimeoutError
 
@@ -26,6 +26,23 @@ class ServerDisconnectedError(DisconnectedError):
     """Server disconnected."""
 
 
+class WSClientDisconnectedError(ClientDisconnectedError):
+    """Raised on closing server websocket."""
+
+    def __init__(self, code=None, message=None):
+        super().__init__(code, message)
+
+    @property
+    def code(self):
+        """Code from websocket closing frame."""
+        return self.args[0]
+
+    @property
+    def message(self):
+        """Message from websocket closing frame."""
+        return self.args[1]
+
+
 class ClientError(Exception):
     """Base class for client connection errors."""
 
@@ -99,8 +116,8 @@ class BadHttpMessage(HttpProcessingError):
     code = 400
     message = 'Bad Request'
 
-    def __init__(self, message):
-        super().__init__(message=message)
+    def __init__(self, message, *, headers=None):
+        super().__init__(message=message, headers=headers)
 
 
 class HttpMethodNotAllowed(HttpProcessingError):
