@@ -13,7 +13,7 @@ from aiohttp.client import ClientRequest, ClientResponse
 
 try:
     import chardet
-except ImportError:
+except ImportError:  # pragma: no cover
     chardet = None
 
 
@@ -158,6 +158,7 @@ class ClientResponseTests(unittest.TestCase):
         self.assertEqual(res, '{"тест": "пройден"}')
         self.assertTrue(self.response.close.called)
 
+    @unittest.skipIf(chardet is None, "no chardet")
     def test_text_detect_encoding(self):
         def side_effect(*args, **kwargs):
             def second_call(*args, **kwargs):
@@ -171,14 +172,27 @@ class ClientResponseTests(unittest.TestCase):
         content.read.side_effect = side_effect
         self.response.close = unittest.mock.Mock()
 
-        if chardet is None:
+        res = self.loop.run_until_complete(self.response.text())
+        self.assertEqual(res, '{"тест": "пройден"}')
+        self.assertTrue(self.response.close.called)
+
+    def test_text_detect_encoding_without_chardet(self):
+        def side_effect(*args, **kwargs):
+            def second_call(*args, **kwargs):
+                raise aiohttp.EofStream
+            fut = asyncio.Future(loop=self.loop)
+            fut.set_result('{"тест": "пройден"}'.encode('cp1251'))
+            content.read.side_effect = second_call
+            return fut
+        self.response.headers = {'CONTENT-TYPE': 'application/json'}
+        content = self.response.content = unittest.mock.Mock()
+        content.read.side_effect = side_effect
+        self.response.close = unittest.mock.Mock()
+
+        with unittest.mock.patch('aiohttp.client.chardet', None):
             self.assertRaises(UnicodeDecodeError,
                               self.loop.run_until_complete,
                               self.response.text())
-        else:
-            res = self.loop.run_until_complete(self.response.text())
-            self.assertEqual(res, '{"тест": "пройден"}')
-            self.assertTrue(self.response.close.called)
 
     def test_json(self):
         def side_effect(*args, **kwargs):
@@ -241,6 +255,7 @@ class ClientResponseTests(unittest.TestCase):
         self.assertEqual(res, {'тест': 'пройден'})
         self.assertTrue(self.response.close.called)
 
+    @unittest.skipIf(chardet is None, "no chardet")
     def test_json_detect_encoding(self):
         def side_effect(*args, **kwargs):
             def second_call(*args, **kwargs):
@@ -254,14 +269,27 @@ class ClientResponseTests(unittest.TestCase):
         content.read.side_effect = side_effect
         self.response.close = unittest.mock.Mock()
 
-        if chardet is None:
+        res = self.loop.run_until_complete(self.response.json())
+        self.assertEqual(res, {'тест': 'пройден'})
+        self.assertTrue(self.response.close.called)
+
+    def test_json_detect_encoding_without_chardet(self):
+        def side_effect(*args, **kwargs):
+            def second_call(*args, **kwargs):
+                raise aiohttp.EofStream
+            fut = asyncio.Future(loop=self.loop)
+            fut.set_result('{"тест": "пройден"}'.encode('cp1251'))
+            content.read.side_effect = second_call
+            return fut
+        self.response.headers = {'CONTENT-TYPE': 'application/json'}
+        content = self.response.content = unittest.mock.Mock()
+        content.read.side_effect = side_effect
+        self.response.close = unittest.mock.Mock()
+
+        with unittest.mock.patch('aiohttp.client.chardet', None):
             self.assertRaises(UnicodeDecodeError,
                               self.loop.run_until_complete,
                               self.response.json())
-        else:
-            res = self.loop.run_until_complete(self.response.json())
-            self.assertEqual(res, {'тест': 'пройден'})
-            self.assertTrue(self.response.close.called)
 
     def test_override_flow_control(self):
         class MyResponse(ClientResponse):
